# -*- coding: utf-8 -*-

from PIL import Image
import argparse

ascii_char = list(
    "$@B%8&WM#*oahkbdpqwmZO0QLCJUYXzcvunxrjft/\|()1{}[]?-_+~<>i!lI;:,\"^`'. ")


# 将256灰度映射到70个字符上
def get_char(r, g, b, alpha=256):
    if alpha == 0:
        return ' '
    length = len(ascii_char)
    gray = int(0.2126 * r + 0.7152 * g + 0.0722 * b)

    unit = (256.0 + 1) / length
    return ascii_char[int(gray / unit)]


def generate(img, width, height, output=None):
    im = Image.open(img)
    im = im.resize((width, height), Image.NEAREST)

    txt = ""

    for i in range(height):
        for j in range(width):
            txt += get_char(*im.getpixel((j, i)))
        txt += '\n'

    print txt

    # 字符画输出到文件
    if output:
        with open(output,'w') as f:
            f.write(txt)


def main():
    # 命令行输入参数处理
    parser = argparse.ArgumentParser()

    parser.add_argument('file')  # 输入文件
    parser.add_argument('-o', '--output')  # 输出文件
    parser.add_argument('--width', type=int, default=80)  # 输出字符画宽
    parser.add_argument('--height', type=int, default=80)  # 输出字符画高

    # 获取参数
    args = parser.parse_args()

    IMG = args.file
    WIDTH = args.width
    HEIGHT = args.height
    OUTPUT = args.output

    generate(IMG, WIDTH, HEIGHT, OUTPUT)


if __name__ == '__main__':
    main()



# coding=utf-8

from setuptools import setup

version = '0.1.5'

entry_points = {
    'console_scripts': [
        'imcii=imcii.ascii:main',
    ],
}

setup(
    name='imcii',
    packages=['imcii'],
    version=version,
    description='imcii = Image to ASCII',
    author='Windard Yang',
    author_email='windard@qq.com',
    url='https://windard.com',

    license="MIT",
    entry_points=entry_points,
)
